pdfplumber.form

Extract AcroForm fields with top-left widget geometry.

Extract AcroForm fields with top-left widget geometry.
raw docstring

export-fdfclj

(export-fdf doc dest)

Export form data to a String/File path or OutputStream and return dest.

Export form data to a String/File path or OutputStream and return `dest`.
sourceraw docstring

field-valuesclj

(field-values doc)

Map of terminal field names to values.

Map of terminal field names to values.
sourceraw docstring

flattenclj

(flatten doc)

Bake form appearances into page content, remove interactive fields, and return doc.

Bake form appearances into page content, remove interactive fields, and return `doc`.
sourceraw docstring

form-fieldsclj

(form-fields doc)

Return a vector of terminal AcroForm fields with first-widget geometry.

Return a vector of terminal AcroForm fields with first-widget geometry.
sourceraw docstring

import-fdfclj

(import-fdf doc source)

Import FDF data from bytes, an InputStream, String path, or File into doc and return it.

Import FDF data from bytes, an InputStream, String path, or File into `doc` and return it.
sourceraw docstring

refresh-appearancesclj

(refresh-appearances doc)

Regenerate appearance streams for all form fields and return doc.

Regenerate appearance streams for all form fields and return `doc`.
sourceraw docstring

set-valuesclj

(set-values doc values)

Set form field values by fully qualified field name and return doc. Text and scalar choice values are strings; multi-select choices accept a collection of strings. Checkbox values are booleans or the checkbox on-value.

Set form field values by fully qualified field name and return `doc`.
Text and scalar choice values are strings; multi-select choices accept a
collection of strings. Checkbox values are booleans or the checkbox on-value.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries