Composable page views for crop, bbox, outside, and predicate filters.
Composable page views for crop, bbox, outside, and predicate filters.
(apply-view objects operations)Apply derived-view operations to extracted object maps in order.
Apply derived-view operations to extracted object maps in order.
(crop source bbox)(crop source bbox {:keys [relative] :as opts})Crop a page view to bbox. It clips partial objects. With :relative true,
bbox coordinates are offsets from the top-left corner of the parent view.
Crop a page view to `bbox`. It clips partial objects. With `:relative true`, bbox coordinates are offsets from the top-left corner of the parent view.
(crop-page source {:keys [bbox] :as opts})Backward-compatible absolute crop view. opts contains :page and :bbox.
Backward-compatible absolute crop view. `opts` contains `:page` and `:bbox`.
(filter source pred)(filter source pred opts)Keep objects when pred returns truthy.
Keep objects when `pred` returns truthy.
(outside-bbox source bbox)(outside-bbox source bbox opts)Keep only objects that do not overlap bbox.
Keep only objects that do not overlap `bbox`.
(page-view? x)True if x is a derived page view.
True if `x` is a derived page view.
(resolve-source source opts)Normalize a document-or-view and extraction options to [doc opts].
Normalize a document-or-view and extraction options to `[doc opts]`.
(within-bbox source bbox)(within-bbox source bbox opts)Keep only objects fully contained by bbox.
Keep only objects fully contained by `bbox`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |