pdfplumber.reducible

Extract objects in one pass, one page at a time.

Extract objects in one pass, one page at a time.
raw docstring

page-reducibleclj

(page-reducible source extractor)
(page-reducible source extractor opts)

Reducible page stream from (extractor doc page-opts). It extracts one page at a time. It stops before later pages when reduction stops early.

Reducible page stream from `(extractor doc page-opts)`. It extracts one page
at a time. It stops before later pages when reduction stops early.
sourceraw docstring

reducible-annotsclj

(reducible-annots source)
(reducible-annots source opts)

Reducible annotation stream.

Reducible annotation stream.
sourceraw docstring

reducible-charsclj

(reducible-chars source)
(reducible-chars source opts)

Single-pass reducible character stream. It extracts one page at a time. A reduced result stops extraction before it visits later pages.

Single-pass reducible character stream. It extracts one page at a time. A
reduced result stops extraction before it visits later pages.
sourceraw docstring

reducible-curvesclj

(reducible-curves source)
(reducible-curves source opts)

Reducible painted-curve stream.

Reducible painted-curve stream.
sourceraw docstring

reducible-imagesclj

(reducible-images source)
(reducible-images source opts)

Reducible drawn-image stream.

Reducible drawn-image stream.
sourceraw docstring

reducible-linesclj

(reducible-lines source)
(reducible-lines source opts)

Reducible painted-line stream.

Reducible painted-line stream.
sourceraw docstring

reducible-objectsclj

(reducible-objects source)
(reducible-objects source opts)

Reducible page-object stream.

Reducible page-object stream.
sourceraw docstring

reducible-rectsclj

(reducible-rects source)
(reducible-rects source opts)

Reducible painted-rectangle stream.

Reducible painted-rectangle stream.
sourceraw docstring

reducible-wordsclj

(reducible-words source)
(reducible-words source opts)

Reducible word stream. It extracts one page at a time.

Reducible word stream. It extracts one page at a time.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries