pdfplumber.core

Public API for pdfplumber-clj: open PDFs and extract text, words, characters, geometric objects, and tables as plain Clojure data.

Public API for pdfplumber-clj: open PDFs and extract text, words, characters,
geometric objects, and tables as plain Clojure data.
raw docstring

annotsclj

(annots source)
(annots source opts)

Page annotations. See pdfplumber.objects/annots.

Page annotations. See `pdfplumber.objects/annots`.
sourceraw docstring

charsclj

(chars source)
(chars source opts)

Vector of character maps. Accepts a document handle or a cropped page view. See pdfplumber.text/chars.

Vector of character maps. Accepts a document handle or a cropped page view.
See `pdfplumber.text/chars`.
sourceraw docstring

cropclj

(crop source bbox)
(crop source bbox opts)

Derived page crop with partial-object clipping.

Derived page crop with partial-object clipping.
sourceraw docstring

crop-pageclj

(crop-page doc opts)

A cropped page view (restricts extraction to a bbox). See pdfplumber.page/crop-page.

A cropped page view (restricts extraction to a bbox). See
`pdfplumber.page/crop-page`.
sourceraw docstring

curvesclj

(curves source)
(curves source opts)

Painted curve objects. See pdfplumber.objects/curves.

Painted curve objects. See `pdfplumber.objects/curves`.
sourceraw docstring

dedupe-charsclj

(dedupe-chars source)
(dedupe-chars source opts)

Extract and deduplicate chars. See pdfplumber.text/dedupe-chars.

Extract and deduplicate chars. See `pdfplumber.text/dedupe-chars`.
sourceraw docstring

edgesclj

(edges source)
(edges source opts)

Normalized page edges. See pdfplumber.objects/edges.

Normalized page edges. See `pdfplumber.objects/edges`.
sourceraw docstring

extract-tableclj

(extract-table source)
(extract-table source opts)

Extract a single table. Accepts a document handle or a cropped page view. See pdfplumber.table/extract-table.

Extract a single table. Accepts a document handle or a cropped page view. See
`pdfplumber.table/extract-table`.
sourceraw docstring

extract-tablesclj

(extract-tables source)
(extract-tables source opts)

Extract tables as a vector. Accepts a document handle or a cropped page view. See pdfplumber.table/extract-tables.

Extract tables as a vector. Accepts a document handle or a cropped page view.
See `pdfplumber.table/extract-tables`.
sourceraw docstring

extract-textclj

(extract-text source)
(extract-text source opts)

Advanced text extraction. See pdfplumber.text/extract-text.

Advanced text extraction. See `pdfplumber.text/extract-text`.
sourceraw docstring

extract-text-linesclj

(extract-text-lines source)
(extract-text-lines source opts)

Positional text lines. See pdfplumber.text/extract-text-lines.

Positional text lines. See `pdfplumber.text/extract-text-lines`.
sourceraw docstring

extract-text-simpleclj

(extract-text-simple source)
(extract-text-simple source opts)

Fast doctop/char-gap text extraction. See pdfplumber.text/extract-text-simple.

Fast doctop/char-gap text extraction. See
`pdfplumber.text/extract-text-simple`.
sourceraw docstring

extract-wordsclj

(extract-words source)
(extract-words source opts)

Advanced word extraction. See pdfplumber.text/extract-words.

Advanced word extraction. See `pdfplumber.text/extract-words`.
sourceraw docstring

filterclj

source

filter-pageclj

(filter-page source pred)
(filter-page source pred opts)

Derived view filtered by an object predicate.

Derived view filtered by an object predicate.
sourceraw docstring

find-tableclj

(find-table source)
(find-table source opts)

Find the first rich Table map. See pdfplumber.table/find-table.

Find the first rich Table map. See `pdfplumber.table/find-table`.
sourceraw docstring

find-tablesclj

(find-tables source)
(find-tables source opts)

Find rich Table maps. See pdfplumber.table/find-tables.

Find rich Table maps. See `pdfplumber.table/find-tables`.
sourceraw docstring

horizontal-edgesclj

(horizontal-edges source)
(horizontal-edges source opts)

Horizontal page edges. See pdfplumber.objects/horizontal-edges.

Horizontal page edges. See `pdfplumber.objects/horizontal-edges`.
sourceraw docstring

(hyperlinks source)
(hyperlinks source opts)

URI link annotations. See pdfplumber.objects/hyperlinks.

URI link annotations. See `pdfplumber.objects/hyperlinks`.
sourceraw docstring

imagesclj

(images source)
(images source opts)

Vector of drawn image objects. Accepts a document handle or a cropped page view. See pdfplumber.objects/images.

Vector of drawn image objects. Accepts a document handle or a cropped page
view. See `pdfplumber.objects/images`.
sourceraw docstring

linesclj

(lines source)
(lines source opts)

Painted line objects. See pdfplumber.objects/lines.

Painted line objects. See `pdfplumber.objects/lines`.
sourceraw docstring

metadataclj

(metadata doc)

Document metadata map. See pdfplumber.document/metadata.

Document metadata map. See `pdfplumber.document/metadata`.
sourceraw docstring

objectsclj

(objects source)
(objects source opts)

Vector of page object maps (lines, rects, curves, images). Accepts a document handle or a cropped page view. See pdfplumber.objects/objects.

Vector of page object maps (lines, rects, curves, images). Accepts a document
handle or a cropped page view. See `pdfplumber.objects/objects`.
sourceraw docstring

objects-by-typeclj

(objects-by-type source)
(objects-by-type source opts)

Object maps grouped by type. See pdfplumber.objects/objects-by-type.

Object maps grouped by type. See `pdfplumber.objects/objects-by-type`.
sourceraw docstring

open-pdfclj

(open-pdf source)

Open a PDF, returning a document handle. See pdfplumber.document/open-pdf. The caller must close it (or use with-pdf).

Open a PDF, returning a document handle. See `pdfplumber.document/open-pdf`.
The caller must close it (or use `with-pdf`).
sourceraw docstring

outside-bboxclj

(outside-bbox source bbox)
(outside-bbox source bbox opts)

Derived view containing only objects outside a bbox.

Derived view containing only objects outside a bbox.
sourceraw docstring

pageclj

(page doc n)

Page map for 1-based page number n. See pdfplumber.document/page.

Page map for 1-based page number `n`. See `pdfplumber.document/page`.
sourceraw docstring

page-view?clj

(page-view? x)

True when x is a cropped page view. See pdfplumber.page/page-view?.

True when `x` is a cropped page view. See `pdfplumber.page/page-view?`.
sourceraw docstring

pagesclj

(pages doc)

Vector of page maps. See pdfplumber.document/pages.

Vector of page maps. See `pdfplumber.document/pages`.
sourceraw docstring

rectsclj

(rects source)
(rects source opts)

Painted rectangle objects. See pdfplumber.objects/rects.

Painted rectangle objects. See `pdfplumber.objects/rects`.
sourceraw docstring

(search source pattern)
(search source pattern opts)

Positional regex or literal search. See pdfplumber.text/search.

Positional regex or literal search. See `pdfplumber.text/search`.
sourceraw docstring

textclj

(text source)
(text source opts)

Reconstructed text string. Accepts a document handle or a cropped page view. See pdfplumber.text/text.

Reconstructed text string. Accepts a document handle or a cropped page view.
See `pdfplumber.text/text`.
sourceraw docstring

text-mapclj

(text-map source)
(text-map source opts)

Text and its source-char mapping. See pdfplumber.text/text-map.

Text and its source-char mapping. See `pdfplumber.text/text-map`.
sourceraw docstring

vertical-edgesclj

(vertical-edges source)
(vertical-edges source opts)

Vertical page edges. See pdfplumber.objects/vertical-edges.

Vertical page edges. See `pdfplumber.objects/vertical-edges`.
sourceraw docstring

with-pdfcljmacro

(with-pdf [binding source] & body)

Open source, bind the document handle to binding, evaluate body, and always close the document on exit (including on exception).

(with-pdf [doc "statement.pdf"]
  (text doc {:page 1}))
Open `source`, bind the document handle to `binding`, evaluate `body`, and
always close the document on exit (including on exception).

    (with-pdf [doc "statement.pdf"]
      (text doc {:page 1}))
sourceraw docstring

within-bboxclj

(within-bbox source bbox)
(within-bbox source bbox opts)

Derived view containing only wholly enclosed objects.

Derived view containing only wholly enclosed objects.
sourceraw docstring

word-mapclj

(word-map source)
(word-map source opts)

Words and their contributing chars. See pdfplumber.text/word-map.

Words and their contributing chars. See `pdfplumber.text/word-map`.
sourceraw docstring

wordsclj

(words source)
(words source opts)

Vector of word maps. Accepts a document handle or a cropped page view. See pdfplumber.text/words.

Vector of word maps. Accepts a document handle or a cropped page view. See
`pdfplumber.text/words`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries