Extract AcroForm fields with top-left widget geometry.
Extract AcroForm fields with top-left widget geometry.
(export-fdf doc dest)Export form data to a String/File path or OutputStream and return dest.
Export form data to a String/File path or OutputStream and return `dest`.
(field-values doc)Map of terminal field names to values.
Map of terminal field names to values.
(flatten doc)Bake form appearances into page content, remove interactive fields, and return doc.
Bake form appearances into page content, remove interactive fields, and return `doc`.
(form-fields doc)Return a vector of terminal AcroForm fields with first-widget geometry.
Return a vector of terminal AcroForm fields with first-widget geometry.
(import-fdf doc source)Import FDF data from bytes, an InputStream, String path, or File into doc and return it.
Import FDF data from bytes, an InputStream, String path, or File into `doc` and return it.
(refresh-appearances doc)Regenerate appearance streams for all form fields and return doc.
Regenerate appearance streams for all form fields and return `doc`.
(set-values doc values)Set form field values by fully qualified field name and return doc.
Text and scalar choice values are strings; multi-select choices accept a
collection of strings. Checkbox values are booleans or the checkbox on-value.
Set form field values by fully qualified field name and return `doc`. Text and scalar choice values are strings; multi-select choices accept a collection of strings. Checkbox values are booleans or the checkbox on-value.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |