pdfplumber.page

Composable derived-page views for crop, bbox, outside, and predicate filters.

Composable derived-page views for crop, bbox, outside, and predicate filters.
raw docstring

apply-viewclj

(apply-view objects operations)

Apply derived-view operations in order to extracted object maps.

Apply derived-view operations in order to extracted object maps.
sourceraw docstring

cropclj

(crop source bbox)
(crop source bbox {:keys [relative] :as opts})

Crop a page view to bbox, clipping partial objects. With :relative true, bbox coordinates are offsets from the parent view's top-left corner.

Crop a page view to `bbox`, clipping partial objects. With `:relative true`,
bbox coordinates are offsets from the parent view's top-left corner.
sourceraw docstring

crop-pageclj

(crop-page source {:keys [bbox] :as opts})

Backward-compatible absolute crop view. opts contains :page and :bbox.

Backward-compatible absolute crop view. `opts` contains `:page` and `:bbox`.
sourceraw docstring

filterclj

(filter source pred)
(filter source pred opts)

Keep objects for which pred returns truthy.

Keep objects for which `pred` returns truthy.
sourceraw docstring

outside-bboxclj

(outside-bbox source bbox)
(outside-bbox source bbox opts)

Keep only objects that do not overlap bbox.

Keep only objects that do not overlap `bbox`.
sourceraw docstring

page-view?clj

(page-view? x)

True when x is a derived page view.

True when `x` is a derived page view.
sourceraw docstring

resolve-sourceclj

(resolve-source source opts)

Normalize a document-or-view plus extraction options into [doc opts].

Normalize a document-or-view plus extraction options into `[doc opts]`.
sourceraw docstring

within-bboxclj

(within-bbox source bbox)
(within-bbox source bbox opts)

Keep only objects fully contained by bbox.

Keep only objects fully contained by `bbox`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries