Composable derived-page views for crop, bbox, outside, and predicate filters.
Composable derived-page views for crop, bbox, outside, and predicate filters.
(apply-view objects operations)Apply derived-view operations in order to extracted object maps.
Apply derived-view operations in order to extracted object maps.
(crop source bbox)(crop source bbox {:keys [relative] :as opts})Crop a page view to bbox, clipping partial objects. With :relative true,
bbox coordinates are offsets from the parent view's top-left corner.
Crop a page view to `bbox`, clipping partial objects. With `:relative true`, bbox coordinates are offsets from the parent view's top-left corner.
(crop-page source {:keys [bbox] :as opts})Backward-compatible absolute crop view. opts contains :page and :bbox.
Backward-compatible absolute crop view. `opts` contains `:page` and `:bbox`.
(filter source pred)(filter source pred opts)Keep objects for which pred returns truthy.
Keep objects for which `pred` returns truthy.
(outside-bbox source bbox)(outside-bbox source bbox opts)Keep only objects that do not overlap bbox.
Keep only objects that do not overlap `bbox`.
(page-view? x)True when x is a derived page view.
True when `x` is a derived page view.
(resolve-source source opts)Normalize a document-or-view plus extraction options into [doc opts].
Normalize a document-or-view plus extraction options into `[doc opts]`.
(within-bbox source bbox)(within-bbox source bbox opts)Keep only objects fully contained by bbox.
Keep only objects fully contained by `bbox`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |